@@ -75,4 +75,8 @@ class TEST_RECOMMENDATION(object):
     interval_sec = 5
     RSS = 'recommendationSetStatus'
     RSS_NOT_READY = 'notready'
+    RSS_NO_HISTORY = 'noHistory'
+    RSS_READY = 'ready'
+    RSS_ERROR = 'error'
+    TEST_SELECTION_ENABLED = "testSelectionEnabled"
 
